% Written by Joshua Simmons 04/01/2016
% Description: used to tranform offshore to nearshore mike21 using the code
% OS2NS_MIKE21.m

clear
clc

%% Settings
%buoy data
buoydataloc = 'J:\Coastal\Data\Wave\Sydney\Processed\SydneyProcessed_CSIROGapFill.mat';
% the non CSIRO filtered data is the only data available after 2014 so fill
% from the recent data with gaps.
backupbuoydata = 'J:\Coastal\Data\Wave\Sydney\Processed\SydneyProcessed.mat';

%location of mike21 runcode
mike21loc = 'J:\Coastal\Tools\Nearshore Wave Transformations\MIKE21\';
%location of MALT
maltloc = 'J:\Coastal\Tools\MALT Logspiral Transformation\';
%location of profiles for which wave data is required.
% profiledataloc = [6275797.660794820 6275692.739810870 6275536.815570840]; % Northings co-ordinate - Bilgola (at 10m contour)
% profiledataloc = [6272148.185 6272338.391 6272389.496 6271924.185 6271823.724]; % Northings co-ordinate - Mona Vale (at 10m contour)
profiledataloc = [6264042.586 6264127.494 6263995.016 6263745.956 6263879.058]; % Northings co-ordinate - Dee Why (at 10m contour)
profiledataloc2 = [343633.9263 343038.1544 342940.1201 342757.2994 342848.2807]; % Eastings co-ordinate - Dee Why (at 10m contour)

site = 'DeeWhy'; %embayment of interest
contour = 10; %m - 10m or 15m contour?

%storm details
stormdatesloc = 'D:\7 Erosion Models\a_nb_model_comparison\input_data\fielddata\stormdates_other.mat';
storm = {'2014', '2015'};

% save?
savebool = 1;
% datasave location
saveloc = 'D:\7 Erosion Models\a_nb_model_comparison\input_data\fielddata\wave\processed\';

%% Code
% for MIKE21 code and MALT
addpath(mike21loc);
addpath(maltloc);
%load buoy data,profile data and lookup table
buoydata = load(buoydataloc);
backupbuoydata = load(backupbuoydata);
load('OEH_ARC_PointOutput.mat');
stormdates = load(stormdatesloc);

% narrow down to date range
for ii = 1:length(storm)
    startdate = stormdates.(['storm_' storm{ii}]).startdate;
    enddate = stormdates.(['storm_' storm{ii}]).enddate;
    
    validentries = find(buoydata.dates>=startdate & buoydata.dates<=enddate);
    % if nothing then revert to backup
    if isempty(validentries) || validentries(end) == length(buoydata.dates)
        validentries = find(backupbuoydata.dates>=startdate & backupbuoydata.dates<=enddate);
        oswaves.Hsig = backupbuoydata.Hsig(validentries);
        oswaves.Tp1 = backupbuoydata.Tp(validentries);
        oswaves.Wdir = backupbuoydata.Wdir(validentries);
        oswaves.datenums = backupbuoydata.dates(validentries);        
    else
        oswaves.Hsig = buoydata.Hsig(validentries);
        oswaves.Tp1 = buoydata.Tp(validentries);
        oswaves.Wdir = buoydata.Wdir(validentries);
        oswaves.datenums = buoydata.dates(validentries);
    end
    
    fns1 = fieldnames(oswaves);
    for kk = 1:length(fns1)
        if any(isnan(oswaves.(fns1{kk})))
            error('NaN values in wave data')
        end
    end
    
    tic
    for jj = 1:length(profiledataloc)
        location.N = profiledataloc(jj);
        location.E = profiledataloc2(jj);
        nswaves = fmikeos2ns(oswaves, LookUps, site, contour, location);
        
        % bug fix to ensure no inaccurate wave period estimates
        nswaves.Tp1 = oswaves.Tp1;
        
        tmp(jj) = nswaves;
    end
    wavedata.ns.data = tmp;
    toc
    
    wavedata.os = oswaves;
    
    wavedata.ns.model = 'MIKE21';
    wavedata.ns.contour = [num2str(contour) 'm'];
    wavedata.ns.location = profiledataloc;
    
    if savebool
        save([saveloc 'wavedata_' lower(site) '_' storm{ii} '.mat'],'wavedata') 
    end
    
    clear wavedata oswaves startdate enddate validentries tmp
end