% Written by Joshua Simmons 04/01/2016
% Description: used to tranform offshore to nearshore mike21 using the code
% OS2NS_MIKE21.m

clear
clc

%% Settings
%buoy data
buoydataloc = 'J:\Coastal\Data\Wave\Sydney\Processed\SydneyProcessed_CSIROGapFill.mat';
% the non CSIRO filtered data is the only data available after 2014 so fill
% from the recent data with gaps.
backupbuoydata = 'J:\Coastal\Data\Wave\Sydney\Processed\SydneyProcessed.mat';

%location of mike21 runcode
mike21loc = 'J:\Coastal\Tools\Nearshore Wave Transformations\MIKE21\';
%location of MALT
maltloc = 'J:\Coastal\Tools\MALT Logspiral Transformation\';
%location of profiles for which wave data is required.
profiledataloc = [90:20:3870]; % s co-ordinate

site = 'Narrabeen'; %embayment of interest
contour = 10; %m - 10m or 15m contour?

%storm details
stormdatesloc = 'D:\7 Erosion Models\a_nb_model_comparison\input_data\fielddata\stormdates_narra.mat';
storm = {'2007', '2011', '2014', '2015'};

% save?
savebool = 0;
% datasave location
saveloc = 'D:\7 Erosion Models\a_nb_model_comparison\input_data\fielddata\wave\processed\';

%% Code
% for MIKE21 code and MALT
addpath(mike21loc);
addpath(maltloc);
%load buoy data,profile data and lookup table
buoydata = load(buoydataloc);
backupbuoydata = load(backupbuoydata);
load('OEH_ARC_PointOutput.mat');
stormdates = load(stormdatesloc);

% narrow down to date range
for ii = 1:length(storm)
    startdate = stormdates.(['storm_' storm{ii}]).startdate;
    enddate = stormdates.(['storm_' storm{ii}]).enddate;
    
    validentries = find(buoydata.dates>=startdate & buoydata.dates<=enddate);
    % if nothing then revert to backup
    if isempty(validentries) || validentries(end) == length(buoydata.dates)
        validentries = find(backupbuoydata.dates>=startdate & backupbuoydata.dates<=enddate);
        oswaves.Hsig = backupbuoydata.Hsig(validentries);
        oswaves.Tp1 = backupbuoydata.Tp(validentries);
        oswaves.Wdir = backupbuoydata.Wdir(validentries);
        oswaves.datenums = backupbuoydata.dates(validentries);        
    else
        oswaves.Hsig = buoydata.Hsig(validentries);
        oswaves.Tp1 = buoydata.Tp(validentries);
        oswaves.Wdir = buoydata.Wdir(validentries);
        oswaves.datenums = buoydata.dates(validentries);
    end
    
    fns1 = fieldnames(oswaves);
    for kk = 1:length(fns1)
        if any(isnan(oswaves.(fns1{kk})))
            error('NaN values in wave data')
        end
    end
    
    tic
    parfor jj = 1:length(profiledataloc)
        location = profiledataloc(jj);
        nswaves = OS2NS_MIKE21(oswaves, LookUps, site, contour, location);
        
        % bug fix to ensure no inaccurate wave period estimates
        nswaves.Tp1 = oswaves.Tp1;
        
%         tmp(jj) = nswaves;
        Hsig(:,jj) = nswaves.Hsig(:,1);
        Wdir(:,jj) = nswaves.Wdir(:,1);
        power(:,jj) = nswaves.power(:,1);
    end
    dataout(ii).s = profiledataloc;
    dataout(ii).Hsig = Hsig;
    dataout(ii).Wdir = Wdir;
    dataout(ii).power = power;
    dataout(ii).osWdir = oswaves.Wdir;
    dataout(ii).osHsig = oswaves.Hsig;
%     wavedata.ns.data = tmp;
    toc
    
    wavedata.os = oswaves;
    
    wavedata.ns.model = 'MIKE21';
    wavedata.ns.contour = [num2str(contour) 'm'];
    wavedata.ns.location = profiledataloc;
    
    if savebool
        save([saveloc 'wavedata_' lower(site) '_' storm{ii} '.mat'],'wavedata') 
    end
    
    clear wavedata oswaves startdate enddate validentries
    clear power s Hsig Wdir
end