% SBEACH toolbox - fsbeach_getdefaults
% Written by Joshua Simmons 11/2017

% returns all the SBEACH default values

%   Syntax:
%   OPT = fsbeach_getdefaults()

function OPT = fsbeach_getdefaults()
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % A - MODEL SETUP
    OPT.TITLE = 'Test';
    OPT.UNITS = 1;
    OPT.NDX = NaN;
    OPT.XSTART = NaN;
    OPT.IDX = 0;
    OPT.DXC = 1;
    OPT.NGRID = 0;
    OPT.DXV = 0;
    OPT.NDXV = 0;
    OPT.NDT = NaN;
    OPT.DT = 5;
    OPT.NWR = 0;
    OPT.WRI = 0;
    OPT.ICOMP = 0;
    OPT.ELV1 = 0;
    OPT.ELV2 = 0.25;
    OPT.ELV3 = 0.5;
    OPT.EDP1 = 0.5;
    OPT.EDP2 = 1;
    OPT.EDP3 = 1.5;
    OPT.REFELV = 0;
    
    % Calibration parameters
    OPT.K = 1.75e-06;
    OPT.EPS = 0.002;
    OPT.LAMM = 0.5;
    
    OPT.TEMPC = 20;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % B - WAVES/WATER ELEVATION/WIND
    OPT.WVTYPE = 2;
    OPT.IWAVE = 1;
    OPT.HIN = 0;
    OPT.T = 0;
    OPT.DTWAV = NaN;
    OPT.IANG = 1;
    OPT.ZIN = 0;
    OPT.DTANG = NaN;
    OPT.DMEAS = NaN; %0 is deepwater
    OPT.IRAND = 0;
    OPT.ISEED = 4567;
    OPT.RPERC = 5;
    OPT.IELEV = 1;
    OPT.TELEV = 0;
    OPT.DTELV = NaN;
    OPT.IWIND = 0;
    OPT.W = 0;
    OPT.ZWIND = 0;
    OPT.DTWND = 60;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % C - BEACH
    OPT.TPIN = 1;
    OPT.SCHEM = 1;
    OPT.XLAND = 0;
    OPT.DLAND = [];
    OPT.XLBDUNE = [];
    OPT.DLBDUNE = [];
    OPT.XLCDUNE = [];
    OPT.DLCDUNE = [];
    OPT.XSCDUNE = [];
    OPT.DSCDUNE = [];
    OPT.XBERMS = [];
    OPT.DBERMS = [];
    OPT.XBERME = [];
    OPT.DBERME = [];
    OPT.XFORS = [];
    OPT.DFORS = [];
    
    %Calibration params
    OPT.DFS = 0.5;
    OPT.D50 = 0.35;
    OPT.BMAX = 17.2;

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % D - BEACH FILL
    OPT.IBCHFILL = 0;
    OPT.XBFS = 0;
    OPT.XBFE = 0;
    OPT.NFILL = 0;
    OPT.XF = [];
    OPT.EFILL = [];
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % E - SEAWALL/REVETMENT
    OPT.ISWALL = 0;
    OPT.XSWALL = 0;
    OPT.ISWFAIL = 0;
    OPT.PEFAIL = 0;
    OPT.WEFAIL = 0;
    OPT.HFAIL = 0;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % F - HARD BOTTOM
    OPT.IHBOT = 0;
    OPT.SCF = 1;
end